import type { ComponentProps } from '@fluentui/react-utilities';
import type { ComponentState } from '@fluentui/react-utilities';
import type { DividerSlots } from '@fluentui/react-divider';
import type { ForwardRefComponent } from '@fluentui/react-utilities';

/**
 * The Divider helps separate content in a site.
 */
export declare const Divider: ForwardRefComponent<DividerProps>;

declare type DividerCommons = {
    /**
     * The color of the Divider.
     *
     * @defaultValue inherit
     */
    color?: 'inherit' | 'brand';
    /**
     * Determines the alignment of the content within the divider.
     * @defaultvalue 'center'
     */
    alignContent: 'start' | 'center' | 'end';
    /**
     * A divider can have one of the preset appearances.
     * When not specified, the divider has its default appearance.
     */
    appearance?: 'brand' | 'strong' | 'subtle';
    /**
     * Adds padding to the beginning and end of the divider.
     * @defaultvalue false
     */
    inset: boolean;
    /**
     * A divider can be horizontal (default) or vertical.
     * @defaultvalue false
     */
    vertical: boolean;
};

export declare type DividerProps = ComponentProps<Partial<DividerSlots>> & Partial<DividerCommons>;

export declare type DividerState = ComponentState<DividerSlots> & DividerCommons;

export declare const useDividerStyles: (state: DividerState) => DividerState;

export { }
